@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2025-11-26'; # DATE
+our $DATE = '2026-01-05'; # DATE
 our $DIST = 'App-FindUtils'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our %SPEC;
 
@@ -108,6 +108,11 @@ sub find_duplicate_filenames {
             my $realpath = Cwd::realpath($_);
             log_debug "Found path $realpath";
 
+            unless ($realpath) {
+                log_warn "Can't find real path for $_: $!, skipped";
+                return;
+            }
+
             if ($args{exclude_filename_regex}) {
                 if ($_ =~ $args{exclude_filename_regex}) {
                     log_info "$_ excluded (matches --exclude-filename-regex: $args{exclude_filename_regex})";
@@ -118,6 +123,10 @@ sub find_duplicate_filenames {
             my $name;
             if ($eval) {
                 $name = $eval->();
+                unless (defined $name) {
+                    log_warn "Eval code produced undef for $_, skipped";
+                    return;
+                }
             } else {
                 $name = $_;
             }
@@ -157,7 +166,7 @@ App::FindUtils - Utilities related to finding files
 
 =head1 VERSION
 
-This document describes version 0.005 of App::FindUtils (from Perl distribution App-FindUtils), released on 2025-11-26.
+This document describes version 0.006 of App::FindUtils (from Perl distribution App-FindUtils), released on 2026-01-05.
 
 =head1 DESCRIPTION
 
@@ -262,7 +271,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2026, 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
